import { AICapacity } from '../../ServiceProxy/Ext/AICapacity';
import { SystemFunction } from '../../Library/Ext/Function/SystemFunction';
import { LoginUserInfo } from '../../Platform/Common/LoginUserInfo';
import { Message } from '../../Communication/Message';
import { PlatformLogger } from '../../Platform/Common/LogSystem/PlatformLogger';
import { JSZip } from 'jszip';

/**
 * 对账系统类
 */
export class Reconciles {
    //#region 单例实现
    private static instance: Reconciles;

    private constructor() {
        this.Separator = "^|";
        this.netBankcomList = [];
    }

    /**
     * 获取单例实例
     */
    public static get Instance(): Reconciles {
        if (!Reconciles.instance) {
            Reconciles.instance = new Reconciles();
        }
        return Reconciles.instance;
    }
    //#endregion

    /**
     * 文件分割符
     */
    private readonly Separator: string;

    //#region 静态字典定义
    /**
     * 证件类型字典
     */
    private static readonly _ID_TYPE_: { [key: string]: string } = {
        "1": "身份证",
        "2": "户口簿",
        "3": "护照",
        "4": "军人证",
        "5": "回乡证",
        "6": "士兵证",
        "7": "港澳居民来往通行证",
        "8": "企业代码证",
        "9": "经营许可证",
        "A": "营业执照",
        "B": "事业法人证书",
        "C": "工商核准号",
        "D": "其他（对公）",
        "E": "临时身份证",
        "F": "外国人居留证",
        "G": "警官证",
        "H": "其他证件（对私）",
        "I": "台湾同胞来往通行证",
        "J": "军官证",
        "K": "文职干部证",
        "L": "军官退休证",
        "M": "文职干部退休证",
        "N": "武警身份证",
        "O": "武警士兵证",
        "P": "武警文职干部证",
        "Q": "武警军官退休证",
        "R": "武警文职干部退休证",
        "S": "机构信用代码证",
        "T": "贷款卡",
    };

    /**
     * 企业规模字典
     */
    private static readonly _COP_SIZE_: { [key: string]: string } = {
        "2": "大型企业",
        "3": "中型企业",
        "4": "小型企业",
        "5": "微型企业",
        "6": "小型企业",
        "9": "其他",
    };

    /**
     * 账户类型字典
     */
    private static readonly _DD_TYPE_: { [key: string]: string } = {
        "1": "基本户",
        "2": "一般户",
        "3": "专用存款户",
        "4": "临时存款户",
        "5": "个人存款户（储蓄户）",
        "6": "协定（理财）户",
        "7": "公积金活期户（个人）",
        "8": "验证户",
    };

    /**
     * 定期存款类型字典
     */
    private static readonly _TD_TYPE_: { [key: string]: string } = {
        "0": "整存整取",
        "1": "零存整取",
        "2": "整存零取",
        "3": "存本取息",
        "4": "通知存款",
        "5": "协议存款",
        "6": "定活两便",
        "7": "教育储蓄",
        "A": "利润最大化通知存款",
    };

    /**
     * 贷款类型字典
     */
    private static readonly _LN_TYPE_: { [key: string]: string } = {
        "1": "普通贷款",
        "2": "按揭贷款",
        "5": "承兑垫款",
        "7": "委托贷款",
        "9": "贴现",
        "A": "授信贷款",
        "B": "卡内融资、质押消费贷款",
        "C": "银/社团贷款",
    };

    /**
     * 账户状态字典
     */
    private static readonly _AC_STS_: { [key: string]: string } = {
        "0": "开户待确认",
        "1": "正常",
        "3": "挂失结清",
        "4": "开户更正",
        "5": "临时销户",
        "6": "久悬",
        "7": "销户申请零余额",
        "8": "销户申请",
        "9": "挂失销户",
        "*": "销户",
        "#": "未激活",
        "A": "损坏卡更换介质申请",
    };

    /**
     * 贷款状态字典
     */
    private static readonly _LN_STS_: { [key: string]: string } = {
        "1": "正常",
        "2": "逾期90天内",
        "3": "呆滞",
        "4": "呆账",
        "5": "逾期90天外",
        "8": "开户未审核",
        "9": "开户撤销",
        "*": "销户",
        "#": "已出表",
    };

    /**
     * 币种字典
     */
    private static readonly _CUR_NO_: { [key: string]: string } = {
        "01": "人民币",
    };

    /**
     * 现转标志字典
     */
    private static readonly _CT_IND_: { [key: string]: string } = {
        "1": "现金",
        "2": "转账",
    };
    //#endregion

    //#region 查询相关方法
    /**
     * 查询机构同步的最新记录
     */
    public QuerySyncInfo(): Array<{ [key: string]: string }> | null {
        const resp = AICapacity.GetInstence().AIRequest("/recon/manage/syncInfo", {});
        if (resp.HasError) {
            return null;
        }
        return resp.Value<Array<{ [key: string]: string }>>("data", null);
    }

    /**
     * 同步数据到分支机构
     * @param branch 机构号
     * @param report 报告回调函数
     */
    public SyncData2Branch(branch: string, report: (tuple: [number, string]) => void): boolean {
        const list = this.QuerySyncInfo();
        if (!list) return false;

        const info = list.find(x => x["branch"] === branch);
        if (!info) return false;

        // 网银同步任务
        if (!info["ext"]) info["ext"] = "{}";
        const ext = JSON.parse(info["ext"]) as { [key: string]: string };
        return this.Work2Daily(branch, ext["sync2netbank"] || "");
    }
    //#endregion

    //#region 账户类定义
    /**
     * 账户信息类
     */
    private class Account {
        /** 客户号 */
        public KHH: string;
        /** 账号 */
        public ZH: string;
        /** 账户类型 */
        public ZHLX: string;
        /** 账户种类 */
        public ZHZL: string;
        /** 产品名称 */
        public CPMC: string;
        /** 产品编号 */
        public CPBH: string;
        /** 账户名称 */
        public ZHMC: string;
        /** 账户序号 */
        public ZHXH: string;
        /** 账户状态 */
        public ZHZT: string;
        /** 余额 */
        public YE: string;
        /** 客户经理 */
        public KHJL: string;
        /** 机构号 */
        public JGH: string;
        /** 联系人信息 */
        public LXRXX: string;
        /** 币种 */
        public BZ: string;
        /** 科目号 */
        public KMH: string;
        /** 科目名称 */
        public KMMC: string;
        /** 明细记录 */
        public Details: Array<{ [key: string]: string }>;
}
    //#endregion

    //#region 日常对账处理
    private netBankcomList: Array<string>;

    /**
     * 处理日常对账
     * @param branch 机构号
     * @param last 上次同步时间
     */
    private Work2Daily(branch: string, last: string): boolean {
    const date = new Date(LoginUserInfo.TradeDate);
    date.setDate(date.getDate() - 1);

    const start = !last ?
        `${date.getFullYear()}${(date.getMonth() + 1).toString().padStart(2, '0')}01` :
        new Date(last).toISOString().slice(0, 10).replace(/-/g, '');

    const end = date.toISOString().slice(0, 10).replace(/-/g, '');

    if (start > end) return false; // 无效区间

    const dt = this.Recon2Netbank(LoginUserInfo.KinbrNo, start, end);
    if (!dt) return false; // 没有获取到网银数据

    return this.uploadReconDetail(branch, end, dt);
}

    /**
     * 网银数据上传和组装txt
     */
    private async uploadReconDetail(branch: string, end: string, dt: any): Promise < boolean > {
    const fileName = `${end}/${branch}_reconDetailInfo`;
    const zip = new JSZip();

    // 处理客户文件
    let content = `~${this.netBankcomList.join(this.Separator)}${this.Separator}\n`;

    for(const row of dt) {
        let rowString = '';
        for (const item of this.netBankcomList) {
            rowString += `${row[item]}${this.Separator}`;
        }
        content += rowString + '\n';
    }

        zip.file(`${fileName}.txt`, content);

    const zipData = await zip.generateAsync({ type: "uint8array" });

    const resp = await AICapacity.GetInstence().UploadFile(
        zipData,
        `${fileName}.zip`,
        10 // 留存10天
    );

    if(resp.HasError) return false;

    // 通知银企对账平台
    const req: UploadNetbank = {
        checkChannel: "NetBank", // 渠道类型
        filePath: resp.Value("data", ""),
        syncEndDate: end, // 结束日期
        branch: LoginUserInfo.KinbrNo // 机构号
    };

    const uploadResp = await AICapacity.GetInstence().AIRequest(
        "/recon/manage/uploadReconDetailByTxt",
        req
    );

    return !uploadResp.HasError;
}

    /**
     * 查询网银对账记录
     */
    private Recon2Netbank(branch: string, start: string, end: string): any {
    // ... 网银对账记录查询逻辑
    // 由于涉及到具体的通信协议和消息格式，这部分代码需要根据实际系统的通信机制来实现
    return null;
}
    //#endregion
}

/**
 * 网银对账数据上传请求类
 */
interface UploadNetbank extends AICapacity.Req {
    checkChannel: string;
    filePath: string;
    syncEndDate: string;
    branch: string;
}
