import { TFInput, TFOutput } from './TFBase'

/**
 * 账户扣款信息接口
 */
export interface AccountDeductInfo {
    /** 账户序号 */
    ZHXH: string
    /** 冻结序号 */
    DJXH: string
    /** 扣划类型 */
    KHLX: string
    /** 扣划周期 */
    KHZQ: string
    /** 起始日期 */
    QSRQ: string
    /** 终止日期 */
    ZZRQ: string
    /** 固定扣划金额 */
    GDKHJE: string
    /** 计划扣划总额 */
    JHKHZE: string
    /** 已扣划总额 */
    YKHZE: string
    /** 已扣划笔数 */
    YKHBS: string
    /** 上次扣划日期 */
    SCKHRQ: string
    /** 扣划机构 */
    KHJG: string
    /** 扣划柜员 */
    KHGY: string
    /** 备注 */
    BZ: string
}

/**
 * 查询账户扣款信息
 * 通过账号查询账户计划扣款信息
 */
export class QueryAccountDeductInfo extends TFOutput {
    /**
     * 账户扣款信息(原始数据)
     * 格式：账户序号|冻结序号|扣划类型|扣划周期|起始日期|终止日期|固定扣划金额|计划扣划总额|已扣划总额|已扣划笔数|上次扣划日期|扣划机构|扣划柜员|备注|
     */
    public ZHKHXX: string = ''

    /**
     * 解析后的账户扣款信息列表
     */
    public get ZHKHXXData(): AccountDeductInfo[] {
        if (!this.ZHKHXX) return []

        return this.ZHKHXX.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                return {
                    ZHXH: fields[0] || '',
                    DJXH: fields[1] || '',
                    KHLX: fields[2] || '',
                    KHZQ: fields[3] || '',
                    QSRQ: fields[4] || '',
                    ZZRQ: fields[5] || '',
                    GDKHJE: fields[6] || '',
                    JHKHZE: fields[7] || '',
                    YKHZE: fields[8] || '',
                    YKHBS: fields[9] || '',
                    SCKHRQ: fields[10] || '',
                    KHJG: fields[11] || '',
                    KHGY: fields[12] || '',
                    BZ: fields[13] || ''
                }
            })
    }

    // #region Input
    /**
     * 查询账户扣款信息的输入参数
     */
    public static Input = class extends TFInput {
        /** 账号 0300 */
        public ZH: string = ''
        /** 账户序号 0340 */
        public ZHXH: string = ''

        /**
         * 执行账户扣款信息查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryAccountDeductInfo()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd34 = this.ZHXH
            this.MessageData.Fd128 = "0012"

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取账户扣款信息数据
            output.ZHKHXX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建账户扣款信息查询的Vue 3组合式API封装
 */
export function useQueryAccountDeductInfo() {
    /**
     * 执行账户扣款信息查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeAccountDeductQuery = (
        params: {
            ZH?: string      // 账号
            ZHXH?: string    // 账户序号
        },
        page: any
    ): QueryAccountDeductInfo => {
        const input = new QueryAccountDeductInfo.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryAccountDeductInfo>(page)
    }

    return {
        executeAccountDeductQuery
    }
}
