import { TFInput, TFOutput } from './TFBase'

/**
 * 账户明细记录接口
 */
export interface AccountDetailRecord {
    /** 交易日期 */
    tradeDate: string
    /** 摘要 */
    summary: string
    /** 现转标志 */
    cashTransferFlag: string
    /** 借贷标志 */
    debitCreditFlag: string
    /** 发生额 */
    amount: string
    /** 余额 */
    balance: string
    /** 交易机构 */
    tradeBranch: string
    /** 交易柜员 */
    teller: string
    /** 流水号 */
    serialNumber: string
    /** 交易时间 */
    tradeTime: string
    /** 凭证号 */
    voucherNumber: string
    /** 代理人姓名 (活期/定期特有) */
    agentName?: string
    /** 代理人证件类型 (活期/定期特有) */
    agentIdType?: string
    /** 代理人证件号码 (活期/定期特有) */
    agentIdNumber?: string
    /** 交易类型 (贷款特有) */
    tradeType?: string
}

/**
 * 查询账户明细
 * 查询活期、定期、内部和贷款账户的交易明细
 */
export class QueryAccountDetail extends TFOutput {
    /**
     * 内容列表(原始数据)
     * 格式：
     * 活期：交易日期|摘要|现转|借贷|发生额|余额|交易机构|交易柜员|流水号|交易时间|凭证号|代理人姓名|代理人证件类型|代理人证件号码|
     * 定期：同上
     * 内部：交易日期|摘要|现转|借贷|发生额|余额|交易机构|交易柜员|流水号|交易时间|凭证号|
     * 贷款：交易日期|摘要|现转|借贷|交易类型|发生额|余额|交易机构|交易柜员|流水号|交易时间|
     */
    public NRLB: string = ''

    /**
     * 解析后的明细记录列表
     */
    public get parsedDetails(): AccountDetailRecord[] {
        if (!this.NRLB) return []

        return this.NRLB.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                // 基础字段(所有账户类型共有)
                const baseRecord: AccountDetailRecord = {
                    tradeDate: fields[0] || '',
                    summary: fields[1] || '',
                    cashTransferFlag: fields[2] || '',
                    debitCreditFlag: fields[3] || '',
                    amount: fields[4] || '',
                    balance: fields[5] || '',
                    tradeBranch: fields[6] || '',
                    teller: fields[7] || '',
                    serialNumber: fields[8] || '',
                    tradeTime: fields[9] || '',
                    voucherNumber: fields[10] || ''
                }

                // 根据账户类型添加特有字段
                if (fields.length > 11) {
                    baseRecord.agentName = fields[11]
                    baseRecord.agentIdType = fields[12]
                    baseRecord.agentIdNumber = fields[13]
                } else if (fields.length > 10 && fields[4] === '3') { // 贷款账户
                    baseRecord.tradeType = fields[10]
                }

                return baseRecord
            })
    }

    // #region Input
    /**
     * 查询账户明细的输入参数
     */
    public static Input = class extends TFInput {
        /** 账号 0380 */
        public ZH: string = ''
        /** 起始日期 0440 (格式:YYYYMMDD) */
        public QSRQ: string = ''
        /** 截止日期 0450 (格式:YYYYMMDD) */
        public JZRQ: string = ''
        /** 账户序号 0510 */
        public ZHXH: string = ''
        /** 查询标志 0660 (1活期 2定期 9内部 3贷款) */
        public CXBZ: string = '1'

        /**
         * 执行账户明细查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryAccountDetail()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd38 = this.ZH
            this.MessageData.Fd44 = this.QSRQ
            this.MessageData.Fd45 = this.JZRQ
            this.MessageData.Fd51 = this.ZHXH
            this.MessageData.Fd66 = this.CXBZ
            this.MessageData.Fd128 = "0073"

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取明细数据
            output.NRLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建账户明细查询的Vue 3组合式API封装
 */
export function useQueryAccountDetail() {
    /**
     * 执行账户明细查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeAccountDetailQuery = (
        params: {
            ZH?: string      // 账号
            QSRQ?: string    // 起始日期(YYYYMMDD)
            JZRQ?: string    // 截止日期(YYYYMMDD)
            ZHXH?: string    // 账户序号
            CXBZ?: string    // 查询标志(1活期 2定期 9内部 3贷款)
        },
        page: any
    ): QueryAccountDetail => {
        const input = new QueryAccountDetail.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryAccountDetail>(page)
    }

    return {
        executeAccountDetailQuery
    }
}
