import { TFInput, TFOutput } from './TFBase'

/**
 * 账户信息接口
 */
export interface AccountInfo {
    /** 账/卡号 */
    ZKH: string
    /** 账号ID */
    ZHID: string
    /** 户名 */
    HM: string
    /** 介质代码 */
    JZDM: string
    /** 介质名称 */
    JZMC: string
    /** 产品代码 */
    CPDM: string
    /** 产品名称 */
    CPMC: string
    /** 凭证号码 */
    PZHM: string
    /** 介质状态 */
    JZZT: string
    /** 支取方式 */
    ZQFS: string
    /** 开户机构 */
    KHJG: string
    /** 启用日期 */
    QYRQ: string
}

/**
 * 查询客户账户信息
 * 通过证件信息查询该客户所有账户
 */
export class QueryAccountInfoByCustomer extends TFOutput {
    /**
     * 账户信息(原始数据)
     * 格式：账/卡号|账号ID|户名|介质代码|介质名称|产品代码|产品名称|凭证号码|介质状态|支取方式|开户机构|启用日期|
     */
    public ZHXX: string = ''

    /**
     * 解析后的账户信息列表
     */
    public get ZHXXData(): AccountInfo[] {
        if (!this.ZHXX) return []

        return this.ZHXX.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                return {
                    ZKH: fields[0] || '',
                    ZHID: fields[1] || '',
                    HM: fields[2] || '',
                    JZDM: fields[3] || '',
                    JZMC: fields[4] || '',
                    CPDM: fields[5] || '',
                    CPMC: fields[6] || '',
                    PZHM: fields[7] || '',
                    JZZT: fields[8] || '',
                    ZQFS: fields[9] || '',
                    KHJG: fields[10] || '',
                    QYRQ: fields[11] || ''
                }
            })
    }

    // #region Input
    /**
     * 查询客户账户信息的输入参数
     */
    public static Input = class extends TFInput {
        /** 户名 0250 */
        public HM: string = ''
        /** 证件号码 102A */
        public ZJHM: string = ''
        /** 证件类型 102G */
        public ZJLX: string = ''
        /** 查询标志 0670 (1-不包含无单折、对公一户通) */
        public CXBZ: string = '1'

        /**
         * 执行客户账户信息查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryAccountInfoByCustomer()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd25 = this.HM
            this.MessageData.Fd102_A = this.ZJHM
            this.MessageData.Fd102_G = this.ZJLX
            this.MessageData.Fd128 = "0009"
            this.MessageData.Fd67 = this.CXBZ

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取账户信息数据
            output.ZHXX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建客户账户信息查询的Vue 3组合式API封装
 */
export function useQueryAccountInfoByCustomer() {
    /**
     * 执行客户账户信息查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeAccountInfoQuery = (
        params: {
            HM?: string      // 户名
            ZJHM?: string    // 证件号码
            ZJLX?: string    // 证件类型
            CXBZ?: string    // 查询标志(1-不包含无单折、对公一户通)
        },
        page: any
    ): QueryAccountInfoByCustomer => {
        const input = new QueryAccountInfoByCustomer.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryAccountInfoByCustomer>(page)
    }

    return {
        executeAccountInfoQuery
    }
}
