import { TFInput, TFOutput } from './TFBase'

/**
 * 下拉菜单项接口
 */
export interface ComboBoxItem {
    /** 类型值 */
    LXZ: string
    /** 描述 */
    MS: string
}

/**
 * 查询下拉框数据
 * 获取前端下拉框所需的数据列表
 */
export class QueryComboBoxData extends TFOutput {
    /**
     * 菜单信息(原始数据)
     * 格式：类型值|描述|
     */
    public CDXX: string = ''

    /**
     * 解析后的菜单信息列表
     */
    public get CDXXData(): ComboBoxItem[] {
        if (!this.CDXX) return []

        return this.CDXX.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                return {
                    LXZ: fields[0] || '',
                    MS: fields[1] || ''
                }
            })
    }

    // #region Input
    /**
     * 查询下拉框数据的输入参数
     */
    public static Input = class extends TFInput {
        /** 列表编码 0640 */
        public LBBM: string = ''
        /** 附属信息 1230 */
        public FJTJ: string = ''

        /**
         * 执行下拉框数据查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryComboBoxData()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K042"
            this.MessageData.Fd64 = this.LBBM
            this.MessageData.Fd123 = this.FJTJ

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取菜单数据
            output.CDXX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建下拉框数据查询的Vue 3组合式API封装
 */
export function useQueryComboBoxData() {
    /**
     * 执行下拉框数据查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeComboBoxQuery = (
        params: {
            LBBM?: string      // 列表编码
            FJTJ?: string      // 附属信息
        },
        page: any
    ): QueryComboBoxData => {
        const input = new QueryComboBoxData.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryComboBoxData>(page)
    }

    return {
        executeComboBoxQuery
    }
}
