import { TFInput, TFOutput } from './TFBase'

/**
 * 客户凭证信息接口
 */
export interface CustomerCertificateInfo {
    /** 账号 */
    ZH: string
    /** 凭证名称 */
    PZMC: string
    /** 种类 */
    ZL: string
    /** 出售未使用 */
    CSWSY: string
    /** 挂失 */
    GS: string
    /** 回收 */
    HS: string
    /** 作废 */
    ZF: string
    /** 使用 */
    SY: string
}

/**
 * 查询客户凭证信息
 * 根据账号或证件，返回客户所有的凭证信息
 */
export class QueryCustomerCertificateList extends TFOutput {
    /**
     * 客户凭证信息(原始数据)
     * 格式：帐号|凭证名称|种类|出售未使用|挂失|回收|作废|使用|
     */
    public KHPZXX: string = ''

    /**
     * 解析后的客户凭证信息列表
     */
    public get KHPZXXData(): CustomerCertificateInfo[] {
        if (!this.KHPZXX) return []

        return this.KHPZXX.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                return {
                    ZH: fields[0] || '',
                    PZMC: fields[1] || '',
                    ZL: fields[2] || '',
                    CSWSY: fields[3] || '',
                    GS: fields[4] || '',
                    HS: fields[5] || '',
                    ZF: fields[6] || '',
                    SY: fields[7] || ''
                }
            })
    }

    // #region Input
    /**
     * 查询客户凭证信息的输入参数
     */
    public static Input = class extends TFInput {
        /** 账号 0300 */
        public ZH: string = ''
        /** 证件号码 0620 */
        public ZJHM: string = ''
        /** 证件类型 0700 */
        public ZJLX: string = ''
        /** 操作标志 0670 */
        public CZBZ: string = ''

        /**
         * 执行客户凭证信息查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryCustomerCertificateList()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "K057"
            this.MessageData.Fd30 = this.ZH
            this.MessageData.Fd62 = this.ZJHM
            this.MessageData.Fd70 = this.ZJLX
            this.MessageData.Fd67 = this.CZBZ

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取客户凭证信息数据
            output.KHPZXX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建客户凭证信息查询的Vue 3组合式API封装
 */
export function useQueryCustomerCertificateList() {
    /**
     * 执行客户凭证信息查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeCertificateQuery = (
        params: {
            ZH?: string      // 账号
            ZJHM?: string    // 证件号码
            ZJLX?: string    // 证件类型
            CZBZ?: string    // 操作标志
        },
        page: any
    ): QueryCustomerCertificateList => {
        const input = new QueryCustomerCertificateList.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryCustomerCertificateList>(page)
    }

    return {
        executeCertificateQuery
    }
}
