import { TFInput, TFOutput } from './TFBase'

/**
 * 客户信息接口
 */
export interface CustomerInfo {
    /** 客户编码 */
    KHBM: string
    /** 证件类型 */
    ZJLX: string
    /** 证件号码 */
    ZJHM: string
    /** 开始日期 */
    KSRQ: string
    /** 结束日期 */
    JSRQ: string
    /** 客户名称 */
    KHMC: string
    /** 客户级别 */
    KHJB: string
    /** 客户别名 */
    KHBM_1: string
    /** 创建日期 */
    CJRQ: string
    /** 手机号 */
    SJH: string
    /** 地址 */
    DZ: string
    /** 公司地址 */
    GSDZ: string
    /** 联系电话 */
    LXDH: string
    /** 性别 */
    XB: string
    /** 贡献度 */
    GXD: string
}

/**
 * 查询客户信息
 * 根据客户号查询客户基本信息
 */
export class QueryCustomerInfoByCode extends TFOutput {
    /**
     * 客户信息(原始数据)
     * 格式：客户编码|证件类型|证件号码|开始日期|结束日期|客户名称|客户级别|客户别名|创建日期|手机号|地址|公司地址|联系电话|性别|贡献度|
     */
    public KHXX: string = ''

    /**
     * 解析后的客户信息列表
     */
    public get KHXXData(): CustomerInfo[] {
        if (!this.KHXX) return []

        return this.KHXX.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                return {
                    KHBM: fields[0] || '',
                    ZJLX: fields[1] || '',
                    ZJHM: fields[2] || '',
                    KSRQ: fields[3] || '',
                    JSRQ: fields[4] || '',
                    KHMC: fields[5] || '',
                    KHJB: fields[6] || '',
                    KHBM_1: fields[7] || '',
                    CJRQ: fields[8] || '',
                    SJH: fields[9] || '',
                    DZ: fields[10] || '',
                    GSDZ: fields[11] || '',
                    LXDH: fields[12] || '',
                    XB: fields[13] || '',
                    GXD: fields[14] || ''
                }
            })
    }

    // #region Input
    /**
     * 查询客户信息的输入参数
     */
    public static Input = class extends TFInput {
        /** 客户号 0280 */
        public KHH: string = ''
        /** 客户类型 0670 (1对私 2对公) */
        public KHLX: string = '1'

        /**
         * 执行客户信息查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryCustomerInfoByCode()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd28 = this.KHH
            this.MessageData.Fd67 = this.KHLX
            this.MessageData.Fd128 = "0036"

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取客户信息数据
            output.KHXX = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建客户信息查询的Vue 3组合式API封装
 */
export function useQueryCustomerInfoByCode() {
    /**
     * 执行客户信息查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeCustomerInfoQuery = (
        params: {
            KHH?: string      // 客户号
            KHLX?: string    // 客户类型(1对私 2对公)
        },
        page: any
    ): QueryCustomerInfoByCode => {
        const input = new QueryCustomerInfoByCode.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryCustomerInfoByCode>(page)
    }

    return {
        executeCustomerInfoQuery
    }
}
