import { TFInput, TFOutput } from './TFBase'

/**
 * 字典数据项接口
 */
export interface DictionaryItem {
    /** 项目编号 */
    XMBH: string
    /** 项目顺序号 */
    XMSXH: string
    /** 内容 */
    NR: string
}

/**
 * 查询字典数据
 * 通过项目编号查询系统字典表中的数据
 */
export class QueryDicData extends TFOutput {
    /**
     * 内容列表(原始数据)
     * 格式：项目编号|项目顺序号|内容|
     */
    public NRLB: string = ''

    /**
     * 解析后的内容列表
     */
    public get NRLBData(): DictionaryItem[] {
        if (!this.NRLB) return []

        return this.NRLB.split('|')
            .filter(record => record.trim().length > 0)
            .map(record => {
                const fields = record.split(',')

                return {
                    XMBH: fields[0] || '',
                    XMSXH: fields[1] || '',
                    NR: fields[2] || ''
                }
            })
    }

    // #region Input
    /**
     * 查询字典数据的输入参数
     */
    public static Input = class extends TFInput {
        /** 项目顺序号 0640 */
        public XMSXH: string = ''
        /** 项目编号 0820 */
        public XMBH: string = ''

        /**
         * 执行字典数据查询
         * @returns 查询结果
         */
        public override Raise(): TFOutput {
            const output = new QueryDicData()

            // 初始化交易数据
            this.PageData.TradeAPIs.InitFd(this.MessageData)
            this.PageData.TradeAPIs.CommSend(this.MessageData)

            // 设置查询参数
            this.MessageData.Fd126_5 = this.MainCode
            this.MessageData.Fd16 = "CXCL"
            this.MessageData.Fd64 = this.XMSXH
            this.MessageData.Fd82 = this.XMBH
            this.MessageData.Fd128 = "0023"

            // 调用服务
            this.PageData.TradeAPIs.CallServer(this.MessageData)

            // 错误处理
            if (this.MessageData.Fd12 != "0000") {
                output.IsFailed = true
                output.FailureCause = this.PageData.TradeAPIs.GetError(this.MessageData)
                return output
            }

            // 获取字典数据
            output.NRLB = this.MessageData.FileData

            return output
        }
    }
    // #endregion
}

/**
 * 创建字典数据查询的Vue 3组合式API封装
 */
export function useQueryDicData() {
    /**
     * 执行字典数据查询
     * @param params 查询参数
     * @param page 页面对象
     * @returns 查询结果
     */
    const executeDicDataQuery = (
        params: {
            XMBH?: string      // 项目编号
            XMSXH?: string     // 项目顺序号
        },
        page: any
    ): QueryDicData => {
        const input = new QueryDicData.Input()

        // 设置查询参数
        Object.assign(input, params)

        // 执行查询
        return input.DoAction<QueryDicData>(page)
    }

    return {
        executeDicDataQuery
    }
}
