/**
 * 根据打包合同号查询录入或已审核的贴现信息
 * 根据合同号查询所有的录入或已审核的贴现信息，返回文件
 */

/**
 * 文件数据项接口
 */
export interface AccordPackingWJItem {
    /** 协议编号 */
    XYBH: string;
    /** 转贴现率 */
    ZTXL: string;
    /** 转贴现利息 */
    ZTXLX: string;
    /** 本地异地 */
    BDYD: string;
    /** 在途天数 */
    ZTTS: string;
    /** 票据类型 */
    PJLX: string;
    /** 票据号码 */
    PJHM: string;
    /** 票面金额 */
    PMJE: string;
    /** 票到期日 */
    PDQR: string;
    /** 申请人名称 */
    SQRMC: string;
    /** 总条数 */
    ZTS: string;
    /** 总票据金额 */
    ZPJJE: string;
    /** 总贴现利息 */
    ZTXLX_1: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccordPackingNumOutput {
    /** 文件内容 */
    WJ: string;
    /** 解析后的文件数据 */
    WJData: AccordPackingWJItem[];
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccordPackingNumInput {
    /** 打包合同号 0620 */
    DBHTH: string;
    /** 区分标志 0670 X录入 2已审核 */
    QFBZ: string;
}

/**
 * 打包合同贴现信息查询服务
 */
export class QueryAccordPackingNumService {
    /**
     * 根据打包合同号查询贴现信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryPackingInfo(
        input: QueryAccordPackingNumInput
    ): Promise<QueryAccordPackingNumOutput> {
        const output: QueryAccordPackingNumOutput = {
            WJ: '',
            WJData: [],
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryPackingInfo', {
            //   mainCode: 'CXCL',
            //   dbhth: input.DBHTH,
            //   qfbz: input.QFBZ,
            //   fileType: '0007'
            // });

            // 模拟API返回数据
            const response = {
                fileData: `XY20230001|0.05|1000|本地|3|电子|E20230001|1000000|20231231|某某公司|1|1000000|1000|`,
                // 其他字段...
            };

            // 解析文件数据
            output.WJ = response.fileData;
            output.WJData = this.analyzeFileData(response.fileData);

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析文件数据
     * @param fileData 文件数据
     * @returns 解析后的数据列表
     */
    private static analyzeFileData(fileData: string): AccordPackingWJItem[] {
        if (!fileData) return [];

        const items = fileData.split('|').filter(item => item.trim() !== '');
        if (items.length < 13) return [];

        return [{
            XYBH: items[0],
            ZTXL: items[1],
            ZTXLX: items[2],
            BDYD: items[3],
            ZTTS: items[4],
            PJLX: items[5],
            PJHM: items[6],
            PMJE: items[7],
            PDQR: items[8],
            SQRMC: items[9],
            ZTS: items[10],
            ZPJJE: items[11],
            ZTXLX_1: items[12]
        }];
    }
}
