/**
 * 根据账号查询分户信息
 * 根据账号查询分户信息
 */

/**
 * 存款账户信息项接口
 */
export interface DepositAccountItem {
    /** 账号 */
    ZH: string;
    /** 账户序号 */
    ZHXH: string;
    /** 户名 */
    HM: string;
    /** 余额 */
    YE: string;
    /** 开户机构 */
    KHJG: string;
    /** 产品名称 */
    CPMC: string;
    /** 开户日期 */
    KHRQ: string;
    /** 账户类型 */
    ZHLX: string;
}

/**
 * 内部账户信息项接口
 */
export interface InternalAccountItem {
    /** 账号 */
    ZH: string;
    /** 户名 */
    HM: string;
    /** 产品名称 */
    CPMC: string;
    /** 余额 */
    YE: string;
    /** 账户类型 */
    ZHLX: string;
}

/**
 * 贷款账户信息项接口
 */
export interface LoanAccountItem {
    /** 账号 */
    ZH: string;
    /** 序号 */
    XH: string;
    /** 户名 */
    HM: string;
    /** 产品名称 */
    CPMC: string;
    /** 余额 */
    YE: string;
    /** 账户类型 */
    ZHLX: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountFHListOutput {
    /** 内容列表原始数据 */
    NRLB: string;
    /** 解析后的存款账户信息列表 */
    depositAccounts: DepositAccountItem[];
    /** 解析后的内部账户信息列表 */
    internalAccounts: InternalAccountItem[];
    /** 解析后的贷款账户信息列表 */
    loanAccounts: LoanAccountItem[];
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountFHListInput {
    /** 账号 0380 */
    ZH: string;
    /** 查询标志 0690 1:存款 2:内部 3:贷款 */
    CXBZ: string;
}

/**
 * 账户分户信息查询服务
 */
export class QueryAccountFHListService {
    /**
     * 根据账号查询分户信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountFHList(
        input: QueryAccountFHListInput
    ): Promise<QueryAccountFHListOutput> {
        const output: QueryAccountFHListOutput = {
            NRLB: '',
            depositAccounts: [],
            internalAccounts: [],
            loanAccounts: [],
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountFHList', {
            //   mainCode: 'CXCL',
            //   zh: input.ZH,
            //   cxbz: input.CXBZ
            // });

            // 模拟API返回数据
            const response = {
                fileData: this.generateMockData(input.CXBZ)
            };

            // 解析文件数据
            output.NRLB = response.fileData;

            // 根据查询标志解析不同类型的数据
            switch (input.CXBZ) {
                case '1': // 存款
                    output.depositAccounts = this.parseDepositAccounts(response.fileData);
                    break;
                case '2': // 内部
                    output.internalAccounts = this.parseInternalAccounts(response.fileData);
                    break;
                case '3': // 贷款
                    output.loanAccounts = this.parseLoanAccounts(response.fileData);
                    break;
            }

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析存款账户信息
     * @param fileData 文件数据
     * @returns 存款账户信息列表
     */
    private static parseDepositAccounts(fileData: string): DepositAccountItem[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 8) return null;

            return {
                ZH: items[0],
                ZHXH: items[1],
                HM: items[2],
                YE: items[3],
                KHJG: items[4],
                CPMC: items[5],
                KHRQ: items[6],
                ZHLX: items[7]
            };
        }).filter(item => item !== null) as DepositAccountItem[];
    }

    /**
     * 解析内部账户信息
     * @param fileData 文件数据
     * @returns 内部账户信息列表
     */
    private static parseInternalAccounts(fileData: string): InternalAccountItem[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 5) return null;

            return {
                ZH: items[0],
                HM: items[1],
                CPMC: items[2],
                YE: items[3],
                ZHLX: items[4]
            };
        }).filter(item => item !== null) as InternalAccountItem[];
    }

    /**
     * 解析贷款账户信息
     * @param fileData 文件数据
     * @returns 贷款账户信息列表
     */
    private static parseLoanAccounts(fileData: string): LoanAccountItem[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 6) return null;

            return {
                ZH: items[0],
                XH: items[1],
                HM: items[2],
                CPMC: items[3],
                YE: items[4],
                ZHLX: items[5]
            };
        }).filter(item => item !== null) as LoanAccountItem[];
    }

    /**
     * 生成模拟数据
     * @param cxbz 查询标志
     * @returns 模拟数据字符串
     */
    private static generateMockData(cxbz: string): string {
        switch (cxbz) {
            case '1': // 存款
                return '622208123456789|001|张三|10000.00|001|活期储蓄|20230101|1|\n622208987654321|002|李四|50000.00|002|定期一年|20230201|2|';
            case '2': // 内部
                return '9000123456|内部账户1|内部产品1|100000.00|3|\n9000987654|内部账户2|内部产品2|200000.00|4|';
            case '3': // 贷款
                return '8000123456|001|王五|个人贷款|50000.00|5|\n8000987654|002|赵六|企业贷款|100000.00|6|';
            default:
                return '';
        }
    }
}
