/**
 * 查询客户账户信息
 * 通过证件信息查询该客户所有账户
 */

/**
 * 账户信息项接口
 */
export interface AccountInfoItem {
    /** 账/卡号 */
    ZKH: string;
    /** 账号ID */
    ZHID: string;
    /** 户名 */
    HM: string;
    /** 介质代码 */
    JZDM: string;
    /** 介质名称 */
    JZMC: string;
    /** 产品代码 */
    CPDM: string;
    /** 产品名称 */
    CPMC: string;
    /** 凭证号码 */
    PZHM: string;
    /** 介质状态 */
    JZZT: string;
    /** 支取方式 */
    ZQFS: string;
    /** 开户机构 */
    KHJG: string;
    /** 启用日期 */
    QYRQ: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountInfoByCustomerOutput {
    /** 账户信息原始数据 */
    ZHXX: string;
    /** 解析后的账户信息列表 */
    ZHXXData: AccountInfoItem[];
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountInfoByCustomerInput {
    /** 户名 0250 */
    HM: string;
    /** 证件号码 102A */
    ZJHM: string;
    /** 证件类型 102G */
    ZJLX: string;
    /** 查询标志 0670 
     * 1-不包含无单折、对公一户通（用于介质相关的交易)
     */
    CXBZ: string;
}

/**
 * 客户账户信息查询服务
 */
export class QueryAccountInfoByCustomerService {
    /**
     * 查询客户账户信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountInfo(
        input: QueryAccountInfoByCustomerInput
    ): Promise<QueryAccountInfoByCustomerOutput> {
        const output: QueryAccountInfoByCustomerOutput = {
            ZHXX: '',
            ZHXXData: [],
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountInfoByCustomer', {
            //   mainCode: 'CXCL',
            //   hm: input.HM,
            //   zjhm: input.ZJHM,
            //   zjlx: input.ZJLX,
            //   cxbz: input.CXBZ,
            //   fileType: '0009'
            // });

            // 模拟API返回数据
            const response = {
                fileData: this.generateMockData()
            };

            // 解析文件数据
            output.ZHXX = response.fileData;
            output.ZHXXData = this.parseFileData(response.fileData);

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析文件数据
     * @param fileData 文件数据
     * @returns 解析后的数据列表
     */
    private static parseFileData(fileData: string): AccountInfoItem[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 11) return null;

            return {
                ZKH: items[0],
                ZHID: items[1],
                HM: items[2],
                JZDM: items[3],
                JZMC: items[4],
                CPDM: items[5],
                CPMC: items[6],
                PZHM: items[7],
                JZZT: items[8],
                ZQFS: items[9],
                KHJG: items[10],
                QYRQ: items[11]
            };
        }).filter(item => item !== null) as AccountInfoItem[];
    }

    /**
     * 生成模拟数据
     * @returns 模拟数据字符串
     */
    private static generateMockData(): string {
        return '622208123456789|001|张三|01|借记卡|001|活期储蓄|123456789|正常|密码|001|20230101|\n' +
            '622208987654321|002|李四|02|存折|002|定期一年|987654321|正常|印鉴|002|20230201|';
    }
}
