/**
 * 账户支付密码器关联查询
 * 查询账户与支付密码器的关联信息
 */

/**
 * 支付密码器关联信息项接口
 */
export interface PaymentDeviceRelation {
    /** 账号 */
    accountNumber: string;
    /** 支付密码器编号 */
    deviceNumber: string;
    /** 本行标志 */
    isBankOwned: string;
    /** 状态 */
    status: string;
    /** 关联日期 */
    relationDate: string;
    /** 解除日期 */
    releaseDate: string;
    /** 机构 */
    branch: string;
    /** 柜员 */
    teller: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountPaymentOutput {
    /** 文件格式数据 */
    fileData: string;
    /** 解析后的支付密码器关联信息列表 */
    relations: PaymentDeviceRelation[];
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountPaymentInput {
    /** 解除日期-结束 0470 */
    releaseDateEnd: string;
    /** 支付密码器编码 0580 */
    deviceNumber: string;
    /** 本行标志 0670 */
    isBankOwned: string;
    /** 解除日期-开始 0460 */
    releaseDateStart: string;
    /** 账号 0300 */
    accountNumber: string;
    /** 关联日期-开始 0440 */
    relationDateStart: string;
    /** 关联日期-结束 0450 */
    relationDateEnd: string;
    /** 关联状态 0680 */
    relationStatus: string;
}

/**
 * 账户支付密码器关联查询服务
 */
export class QueryAccountPaymentService {
    /**
     * 查询账户支付密码器关联信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountPayment(
        input: QueryAccountPaymentInput
    ): Promise<QueryAccountPaymentOutput> {
        const output: QueryAccountPaymentOutput = {
            fileData: '',
            relations: [],
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountPayment', {
            //   mainCode: 'CXCL',
            //   accountNumber: input.accountNumber,
            //   deviceNumber: input.deviceNumber,
            //   isBankOwned: input.isBankOwned,
            //   releaseDateStart: input.releaseDateStart,
            //   releaseDateEnd: input.releaseDateEnd,
            //   relationDateStart: input.relationDateStart,
            //   relationDateEnd: input.relationDateEnd,
            //   relationStatus: input.relationStatus,
            //   fileType: '0078'
            // });

            // 模拟API返回数据
            const response = {
                fileData: this.generateMockData()
            };

            // 解析文件数据
            output.fileData = response.fileData;
            output.relations = this.parseFileData(response.fileData);

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析文件数据
     * @param fileData 文件数据
     * @returns 解析后的支付密码器关联信息列表
     */
    private static parseFileData(fileData: string): PaymentDeviceRelation[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 8) return null;

            return {
                accountNumber: items[0],
                deviceNumber: items[1],
                isBankOwned: items[2],
                status: items[3],
                relationDate: items[4],
                releaseDate: items[5],
                branch: items[6],
                teller: items[7]
            };
        }).filter(item => item !== null) as PaymentDeviceRelation[];
    }

    /**
     * 生成模拟数据
     * @returns 模拟数据字符串
     */
    private static generateMockData(): string {
        return '622208123456789|DEV001|1|正常|20230101|20231231|001|T001|\n' +
            '622208987654321|DEV002|0|解除|20230201|20231130|002|T002|';
    }
}
