/**
 * 账户印鉴卡/支付密码器关联查询
 * 根据账户或印鉴卡/支付密码器查询关联信息
 */

/**
 * 关联信息项接口
 */
export interface AccountPaymentPwdConnection {
    /** 账号 */
    accountNumber: string;
    /** 印鉴/支付密码器 */
    sealOrDevice: string;
    /** 凭证编号 */
    voucherNumber: string;
    /** 本行标识 */
    isBankOwned: string;
    /** 关联状态 */
    relationStatus: string;
    /** 关联日期 */
    relationDate: string;
    /** 解除日期 */
    releaseDate: string;
    /** 交易机构 */
    transactionBranch: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountPaymentPwdConnectionOutput {
    /** 文件列表原始数据 */
    fileData: string;
    /** 解析后的关联信息列表 */
    connections: AccountPaymentPwdConnection[];
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountPaymentPwdConnectionInput {
    /** 账号 0300 */
    accountNumber: string;
    /** 印鉴卡/支付密码编号 0580 */
    sealOrDeviceNumber: string;
    /** 本行标识 0670 Y.本行 N.他行 */
    isBankOwned: string;
    /** 凭证种类 0890 117:支付密码器 188:印鉴卡 */
    voucherType: string;
    /** 机构号 0910 账号的开户机构 */
    branchNumber: string;
    /** 关联公用标志/出售 0690 Y.关联 N.公用 */
    relationFlag: string;
}

/**
 * 账户印鉴卡/支付密码器关联查询服务
 */
export class QueryAccountPaymentPwdConnectionService {
    /**
     * 查询账户印鉴卡/支付密码器关联信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountPaymentPwdConnection(
        input: QueryAccountPaymentPwdConnectionInput
    ): Promise<QueryAccountPaymentPwdConnectionOutput> {
        const output: QueryAccountPaymentPwdConnectionOutput = {
            fileData: '',
            connections: [],
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountPaymentPwdConnection', {
            //   mainCode: 'CXCL',
            //   accountNumber: input.accountNumber,
            //   sealOrDeviceNumber: input.sealOrDeviceNumber,
            //   isBankOwned: input.isBankOwned,
            //   voucherType: input.voucherType,
            //   branchNumber: input.branchNumber,
            //   relationFlag: input.relationFlag,
            //   fileType: '0057'
            // });

            // 模拟API返回数据
            const response = {
                fileData: this.generateMockData(input.voucherType)
            };

            // 解析文件数据
            output.fileData = response.fileData;
            output.connections = this.parseFileData(response.fileData);

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 解析文件数据
     * @param fileData 文件数据
     * @returns 解析后的关联信息列表
     */
    private static parseFileData(fileData: string): AccountPaymentPwdConnection[] {
        if (!fileData) return [];

        const lines = fileData.split('\n').filter(line => line.trim() !== '');
        return lines.map(line => {
            const items = line.split('|').filter(item => item.trim() !== '');
            if (items.length < 8) return null;

            return {
                accountNumber: items[0],
                sealOrDevice: items[1],
                voucherNumber: items[2],
                isBankOwned: items[3],
                relationStatus: items[4],
                relationDate: items[5],
                releaseDate: items[6],
                transactionBranch: items[7]
            };
        }).filter(item => item !== null) as AccountPaymentPwdConnection[];
    }

    /**
     * 生成模拟数据
     * @param voucherType 凭证类型
     * @returns 模拟数据字符串
     */
    private static generateMockData(voucherType: string): string {
        if (voucherType === '117') {
            // 支付密码器
            return '622208123456789|支付密码器|DEV001|Y|关联|20230101|20231231|001|\n' +
                '622208987654321|支付密码器|DEV002|N|解除|20230201|20231130|002|';
        } else {
            // 印鉴卡
            return '622208123456789|印鉴卡|SEAL001|Y|关联|20230101|20231231|001|\n' +
                '622208987654321|印鉴卡|SEAL002|N|解除|20230201|20231130|002|';
        }
    }
}
