/**
 * 账户通存通兑信息查询
 * 查询账户的通存通兑签约信息
 */

/**
 * 通存通兑信息接口
 */
export interface AccountTCTDInfo {
    /** 签约日期 0440 */
    signDate: string;
    /** 解约日期 0450 */
    cancelDate: string;
    /** 通存范围 0680 */
    depositRange: string;
    /** 通兑范围 0690 */
    withdrawalRange: string;
    /** 状态 0700 1.正常 N.解约或未签约 */
    status: string;
    /** 交易机构和开户机构能否通存 0710 Y.是 N.否 */
    canDeposit: string;
    /** 现金单笔限额 1001 */
    cashSingleLimit: string;
    /** 现金单日累计 1002 */
    cashDailyTotal: string;
    /** 转账单笔限额 1003 */
    transferSingleLimit: string;
    /** 转账单日累计 1004 */
    transferDailyTotal: string;
    /** 单日现金发生额 0390 */
    dailyCashAmount: string;
    /** 单日转账发生额 0400 */
    dailyTransferAmount: string;
    /** 交易机构和开户机构能否通兑 0720 Y.是 N.否 */
    canWithdraw: string;
}

/**
 * 输出参数接口
 */
export interface QueryAccountTCTDOutput {
    /** 通存通兑信息 */
    tctdInfo: AccountTCTDInfo;
    /** 是否失败 */
    IsFailed: boolean;
    /** 失败原因 */
    FailureCause: string;
}

/**
 * 输入参数接口
 */
export interface QueryAccountTCTDInput {
    /** 账号 0300 */
    accountNumber: string;
    /** 账户序号 0340 */
    accountIndex: string;
}

/**
 * 账户通存通兑信息查询服务
 */
export class QueryAccountTCTDService {
    /**
     * 查询账户通存通兑信息
     * @param input 输入参数
     * @returns 查询结果
     */
    public static async queryAccountTCTD(
        input: QueryAccountTCTDInput
    ): Promise<QueryAccountTCTDOutput> {
        const output: QueryAccountTCTDOutput = {
            tctdInfo: {
                signDate: '',
                cancelDate: '',
                depositRange: '',
                withdrawalRange: '',
                status: '',
                canDeposit: '',
                cashSingleLimit: '',
                cashDailyTotal: '',
                transferSingleLimit: '',
                transferDailyTotal: '',
                dailyCashAmount: '',
                dailyTransferAmount: '',
                canWithdraw: ''
            },
            IsFailed: false,
            FailureCause: ''
        };

        try {
            // 替换原有的后端API调用
            // const response = await api.post('/trade/queryAccountTCTD', {
            //   mainCode: 'K065',
            //   accountNumber: input.accountNumber,
            //   accountIndex: input.accountIndex
            // });

            // 模拟API返回数据
            const response = {
                data: this.generateMockData()
            };

            // 处理返回数据
            output.tctdInfo = {
                signDate: response.data.signDate,
                cancelDate: response.data.cancelDate,
                depositRange: response.data.depositRange,
                withdrawalRange: response.data.withdrawalRange,
                status: response.data.status,
                canDeposit: response.data.canDeposit,
                cashSingleLimit: response.data.cashSingleLimit,
                cashDailyTotal: response.data.cashDailyTotal,
                transferSingleLimit: response.data.transferSingleLimit,
                transferDailyTotal: response.data.transferDailyTotal,
                dailyCashAmount: response.data.dailyCashAmount,
                dailyTransferAmount: response.data.dailyTransferAmount,
                canWithdraw: response.data.canWithdraw
            };

            return output;
        } catch (error) {
            output.IsFailed = true;
            output.FailureCause = error instanceof Error ? error.message : '查询失败';
            return output;
        }
    }

    /**
     * 生成模拟数据
     * @returns 模拟数据
     */
    private static generateMockData(): any {
        return {
            signDate: '20230101',
            cancelDate: '',
            depositRange: '全国',
            withdrawalRange: '全省',
            status: '1',
            canDeposit: 'Y',
            cashSingleLimit: '50000',
            cashDailyTotal: '200000',
            transferSingleLimit: '100000',
            transferDailyTotal: '500000',
            dailyCashAmount: '0',
            dailyTransferAmount: '0',
            canWithdraw: 'Y'
        };
    }
}
