/**
 * 交易功能基础类
 * 提供所有交易功能的基类和方法
 */

import { PageBase } from './PageBase'
import { Message } from './Message'

/**
 * 输入参数基类
 */
export abstract class TFInput {
    /**
     * 主交易码
     */
    public MainCode: string = ''

    /**
     * 是否提示警告信息
     */
    public IsShowWarning: boolean = true

    /**
     * 页面数据对象
     */
    protected PageData!: PageBase

    /**
     * 消息数据对象
     */
    protected MessageData!: Message

    constructor() {
        this.IsShowWarning = true
    }

    /**
     * 去空格函数
     * @param str 输入字符串
     * @returns 去除空格后的字符串
     */
    protected DelSpace(str: string): string {
        return str.trim()
    }

    /**
     * 格式化成数字
     * @param str 输入字符串
     * @returns 格式化后的数字字符串
     */
    protected Number(str: string): string {
        const temp = parseFloat(str.trim())
        return isNaN(temp) ? str : temp.toString()
    }

    /**
     * 执行逻辑数据填充
     * @returns 操作结果
     */
    public abstract Raise(): TFOutput

    /**
     * 执行操作
     * @template T 输出类型
     * @param page 页面对象
     * @returns 操作结果
     */
    public DoAction<T extends TFOutput>(page: any): T {
        this.LoadData(page, new Message())

        // 获取主交易码
        if (!this.MainCode) {
            this.MainCode = page.TradeInfo.MainCode
        }

        const ret = this.Raise() as T

        // 若返回WARN，则进行提示
        if (this.IsShowWarning && this.MessageData.Fd12 === "WARN") {
            this.PageData.TradeAPIs.ShowWarnMessageBox(
                this.PageData.TradeAPIs.GetError(this.MessageData)
            )
            ret.IsFailed = false
        }

        return ret
    }

    /**
     * 加载数据
     * @param page 页面对象
     * @param message 消息对象
     */
    protected LoadData(page: any, message: Message): void {
        this.PageData = page
        this.MessageData = message
    }

    /**
     * 解析列表数据，format按照|分隔进行
     * @template T 返回数据类型
     * @param fileData 文件数据
     * @param format 格式字符串
     * @param action 处理函数
     * @returns 解析后的数据列表
     */
    public static AnilyzeFileData<T>(
        fileData: string,
        format: string,
        action: (dict: Record<string, string>) => T
    ): T[] {
        const ret: T[] = []

        if (!fileData || !format) {
            return ret
        }

        const sr = new StringReader(fileData)
        let line = sr.ReadLine()

        // 处理格式行
        if (line?.startsWith("~")) {
            const cols = line.substring(1).split('|')
            const tmp: Record<string, string> = {}

            cols.forEach(col => {
                const cnt = Object.values(tmp).filter(v => v === col).length
                tmp[col + (cnt > 0 ? cnt.toString() : "")] = col
            })

            format = Object.keys(tmp).join("|")
            line = sr.ReadLine()
        }

        const colNames = format.split('|')

        // 处理数据行
        while (line) {
            if (!line.startsWith("~")) {
                const rowData = line.split('|')
                const dict: Record<string, string> = {}

                colNames.forEach((col, i) => {
                    if (col) {
                        dict[col] = rowData[i] || ''
                    }
                })

                ret.push(action(dict))
            }
            line = sr.ReadLine()
        }

        return ret
    }

    /**
     * 按格式解析返回字典
     * @param fileData 文件数据
     * @param formatString 格式字符串
     * @returns 解析后的字典
     */
    public static AnilyzeFileData(
        fileData: string,
        formatString: string
    ): Record<string, string> {
        const dict: Record<string, string> = {}

        if (!fileData || !formatString) {
            return dict
        }

        // 解析格式化字符串
        const lengths = formatString.toLowerCase().split(/[otv]/)
        let cellLength = 0
        let titleIndex = 0
        let titleLength = 0
        let valueIndex = 0
        let valueLength = 0
        let counter = 0

        for (let i = 1; i < lengths.length; i++) {
            const length = parseInt(lengths[i])
            const type = formatString[counter]

            switch (type) {
                case 't':
                    titleIndex = cellLength
                    titleLength = length
                    break
                case 'v':
                    valueIndex = cellLength
                    valueLength = length
                    break
                case 'o':
                    break
                default:
                    return dict
            }

            counter++
            counter += lengths[i].length
            cellLength += length
        }

        // 处理数据
        const data = new TextEncoder().encode(fileData)
        const count = data.length / cellLength

        for (let i = 0; i < count; i++) {
            const titleBytes = data.slice(
                titleIndex + i * cellLength,
                titleIndex + i * cellLength + titleLength
            )
            const title = new TextDecoder().decode(titleBytes).trim()

            const valueBytes = data.slice(
                valueIndex + i * cellLength,
                valueIndex + i * cellLength + valueLength
            )
            const value = new TextDecoder().decode(valueBytes)

            dict[title] = value
        }

        return dict
    }
}

/**
 * 输出结果基类
 */
export abstract class TFOutput {
    /**
     * 执行结果
     */
    public IsFailed: boolean = false

    /**
     * 失败原因
     */
    public FailureCause: string = ''

    /**
     * 设置失败标志
     * @param failureCause 失败原因
     */
    public SetFailure(failureCause: string): void {
        this.IsFailed = true
        this.FailureCause = failureCause
    }
}

/**
 * 字符串读取器模拟类
 */
class StringReader {
    private str: string
    private pos: number = 0

    constructor(str: string) {
        this.str = str
    }

    /**
     * 读取一行
     * @returns 读取的行或null
     */
    public ReadLine(): string | null {
        if (this.pos >= this.str.length) {
            return null
        }

        const lineEnd = this.str.indexOf('\n', this.pos)
        const line = lineEnd === -1
            ? this.str.substring(this.pos)
            : this.str.substring(this.pos, lineEnd)

        this.pos = lineEnd === -1 ? this.str.length : lineEnd + 1
        return line.replace(/\r$/, '')
    }
}
